==> activity-center-api-1.4.13-20170414.121004-1-sources.jar: cn/com/duiba/activity/center/api/dto/hdtool/HdtoolOptionsDto.java <==
package cn.com.duiba.activity.center.api.dto.hdtool;

import java.io.Serializable;
import java.util.Date;

/**
 * 兑吧活动工具奖项
 */
public class HdtoolOptionsDto implements Serializable {

	/**
     * serialVersionUID:(用一句话描述这个变量表示什么).
     * @since JDK 1.6
     */
    private static final long serialVersionUID = 45201095905935859L;
    private Long id;
	private Long operatingActivityId;
	private Long duibaHdtoolId;
	private String name;
	private Integer payload;
	private Long appItemId;
	private Long itemId;
	private String prizeType;
	private String facePrice;
	private String logo;
	private Integer remaining;
	private String rate;
	private Boolean hidden;
	private String description;
	private Integer limitCount;
	private Integer minComein;
	private Boolean deleted;
	private Date gmtCreate;
	private Date gmtModified;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getOperatingActivityId() {
		return operatingActivityId;
	}

	public void setOperatingActivityId(Long operatingActivityId) {
		this.operatingActivityId = operatingActivityId;
	}

	public Long getDuibaHdtoolId() {
		return duibaHdtoolId;
	}

	public void setDuibaHdtoolId(Long duibaHdtoolId) {
		this.duibaHdtoolId = duibaHdtoolId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Integer getPayload() {
		return payload;
	}

	public void setPayload(Integer payload) {
		this.payload = payload;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public String getPrizeType() {
		return prizeType;
	}

	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}

	public String getFacePrice() {
		return facePrice;
	}

	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}

	public String getLogo() {
		return logo;
	}

	public void setLogo(String logo) {
		this.logo = logo;
	}

	public Integer getRemaining() {
		return remaining;
	}

	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}

	public String getRate() {
		return rate;
	}

	public void setRate(String rate) {
		this.rate = rate;
	}

	public Boolean getHidden() {
		return hidden;
	}

	public void setHidden(Boolean hidden) {
		this.hidden = hidden;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Integer getLimitCount() {
		return limitCount;
	}

	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}

	public Integer getMinComein() {
		return minComein;
	}

	public void setMinComein(Integer minComein) {
		this.minComein = minComein;
	}

	public Boolean getDeleted() {
		return deleted;
	}

	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

}

==> activity-center-api-3.6.26-20250907.112748-9-sources.jar: cn/com/duiba/activity/center/api/dto/hdtool/HdtoolOptionsDto.java <==
package cn.com.duiba.activity.center.api.dto.hdtool;

import java.io.Serializable;
import java.util.Date;

/**
 * 兑吧活动工具奖项
 */
public class HdtoolOptionsDto implements Serializable {

	/**
     * serialVersionUID:(用一句话描述这个变量表示什么).
     * @since JDK 1.6
     */
    private static final long serialVersionUID = 45201095905935859L;
    private Long id;
	private Long operatingActivityId;
	private Long duibaHdtoolId;
	private String name;
	private Integer payload;
	private Long appItemId;
	private Long itemId;
	private String prizeType;
	private String facePrice;
	private String logo;
	private Integer remaining;
	private String rate;
	private Boolean hidden;
	private String description;
	private Integer limitCount;
	private Integer minComein;
	private Boolean deleted;
	private Boolean autoOpen;
	private Date gmtCreate;
	private Date gmtModified;
	private Integer rolling;

	public void setRolling(Integer rolling) {
		this.rolling = rolling;
	}

	public Integer getRolling() {
		return rolling;
	}

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getOperatingActivityId() {
		return operatingActivityId;
	}

	public void setOperatingActivityId(Long operatingActivityId) {
		this.operatingActivityId = operatingActivityId;
	}

	public Long getDuibaHdtoolId() {
		return duibaHdtoolId;
	}

	public void setDuibaHdtoolId(Long duibaHdtoolId) {
		this.duibaHdtoolId = duibaHdtoolId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Integer getPayload() {
		return payload;
	}

	public void setPayload(Integer payload) {
		this.payload = payload;
	}

	public Long getAppItemId() {
		return appItemId;
	}

	public void setAppItemId(Long appItemId) {
		this.appItemId = appItemId;
	}

	public Long getItemId() {
		return itemId;
	}

	public void setItemId(Long itemId) {
		this.itemId = itemId;
	}

	public String getPrizeType() {
		return prizeType;
	}

	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}

	public String getFacePrice() {
		return facePrice;
	}

	public void setFacePrice(String facePrice) {
		this.facePrice = facePrice;
	}

	public String getLogo() {
		return logo;
	}

	public void setLogo(String logo) {
		this.logo = logo;
	}

	public Integer getRemaining() {
		return remaining;
	}

	public void setRemaining(Integer remaining) {
		this.remaining = remaining;
	}

	public String getRate() {
		return rate;
	}

	public void setRate(String rate) {
		this.rate = rate;
	}

	public Boolean getHidden() {
		return hidden;
	}

	public void setHidden(Boolean hidden) {
		this.hidden = hidden;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public Integer getLimitCount() {
		return limitCount;
	}

	public void setLimitCount(Integer limitCount) {
		this.limitCount = limitCount;
	}

	public Integer getMinComein() {
		return minComein;
	}

	public void setMinComein(Integer minComein) {
		this.minComein = minComein;
	}

	public Boolean getDeleted() {
		return deleted;
	}

	public void setDeleted(Boolean deleted) {
		this.deleted = deleted;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}

	public Boolean getAutoOpen() {
		return autoOpen;
	}

	public void setAutoOpen(Boolean autoOpen) {
		this.autoOpen = autoOpen;
	}
}
